API Reference
=============

This section contains the complete API reference for the Gradium Python client.

GradiumClient
-------------

.. autoclass:: gradium.GradiumClient
   :members:
   :undoc-members:
   :show-inheritance:

Speech Module
-------------

The speech module provides Text-to-Speech (TTS) and Speech-to-Text (STT) functionality.

TTSSetup
~~~~~~~~

.. autoclass:: gradium.TTSSetup
   :members:
   :undoc-members:
   :show-inheritance:

STTSetup
~~~~~~~~

.. autoclass:: gradium.STTSetup
   :members:
   :undoc-members:
   :show-inheritance:

Speech Functions
~~~~~~~~~~~~~~~~

.. automodule:: gradium.speech
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: TTSSetup, STTSetup

Voices Module
-------------

The voices module provides voice creation and management functionality.

.. automodule:: gradium.voices
   :members:
   :undoc-members:
   :show-inheritance:

Usages Module
-------------

The usages module provides credit and usage tracking functionality.

.. automodule:: gradium.usages
   :members:
   :undoc-members:
   :show-inheritance:
